Enum xcm_calls::assets::AssetsCall [−][src]
pub enum AssetsCall<AssetId, Source, Balance> {
Mint(AssetParams<AssetId, Source, Balance>),
Burn(AssetParams<AssetId, Source, Balance>),
Transfer(AssetParams<AssetId, Source, Balance>),
ForceTransfer(AssetId, Source, Source, Balance),
Freeze(AssetId, Source),
Thaw(AssetId, Source),
FreezeAsset(AssetId),
ThawAsset(AssetId),
ApproveTransfer(AssetParams<AssetId, Source, Balance>),
CancelApproval(AssetId, Source),
TransferApproved(AssetId, Source, Source, Balance),
}Expand description
Represents dispatchable calls of the FRAME pallet_assets pallet.
NOTE: Balance and AssetId are expected to encode with HasCompact
Variants
Mint(AssetParams<AssetId, Source, Balance>)The mint extrinsic.
Mint assets of a particular class.
The origin must be Signed and the sender must be the Issuer of the asset id.
Tuple Fields of Mint
0: AssetParams<AssetId, Source, Balance>Burn(AssetParams<AssetId, Source, Balance>)The burn extrinsic.
Reduce the balance of who by as much as possible up to amount assets of id.
Origin must be Signed and the sender should be the Manager of the asset id.
Tuple Fields of Burn
0: AssetParams<AssetId, Source, Balance>Transfer(AssetParams<AssetId, Source, Balance>)The transfer extrinsic.
Move some assets from the sender account to another.
Tuple Fields of Transfer
0: AssetParams<AssetId, Source, Balance>The force_transfer extrinsic.
Same as Transfer but debit the source instead of the origin
[id, source, dest, amount ]
The freeze extrinsic.
Disallow further unprivileged transfers from an account.
The thaw extrinsic.
Allow unprivileged transfers from an account again.
The freeze_asset extrinsic.
Disallow further unprivileged transfers for the asset class.
The freeze_asset extrinsic.
Allow unprivileged transfers for the asset again.
ApproveTransfer(AssetParams<AssetId, Source, Balance>)The approve_transfer extrinsic.
Approve an amount of asset for transfer by a delegated third-party account. [id, delegate, amount ]
Tuple Fields of ApproveTransfer
0: AssetParams<AssetId, Source, Balance>The cancel_approval extrinsic.
Cancel all of some asset approved for delegated transfer by a third-party account. [id, delegate ]
The transfer_approved extrinsic.
Transfer some asset balance from a previously delegated account to some third-party account. [id, owner, destination, amount ]