Struct xcm_calls::staking::StakingConfig [−][src]
pub struct StakingConfig<AccountId, Balance, BlockNumber> {
pub pallet_index: u8,
pub reward_destination: RewardDestination<AccountId>,
pub minimum_balance: Balance,
pub weights: StakingWeights,
pub bonding_duration: BlockNumber,
pub is_frozen: bool,
}Expand description
The pallet_staking configuration for a particular chain
Fields
pallet_index: u8The index of pallet_index within the parachain’s runtime
reward_destination: RewardDestination<AccountId>The configured reward destination
minimum_balance: BalanceThe specified minimum_balance specified the parachain’s T::Currency
weights: StakingWeightsThe configured weights for pallet_staking
bonding_duration: BlockNumberThis measures the time that must pass until unbonded funds can be withdrawn measured in
BlockNumbers
NOTE: It is expected that this is already the duration measured in PINT parachain blocks
and NOT in remote chain blocks. This involves converting the block time of the other chain
to the block time of PINT. The bonding_duration as it’s expected here is
BondDuration * EPOCH_DURATION_IN_BLOCKS * SessionsPerEra * (MILLISEC_PER_BLOCK_other / MILLISEC_PER_BLOCK_pint)is_frozen: boolWhether the asset is frozen for xcm related transfers.