Struct xcm_calls::staking::StakingDurations [−][src]
pub struct StakingDurations {
pub slot_duration: u64,
pub epoch_duration: u64,
pub bonding_duration: u64,
}Expand description
Represents all staking related durations required to determine the correct chain-specific bonding duration.
Fields
slot_duration: u64This determines the average expected block time that the chain is targeting.
This is essentially the block time in milliseconds.
epoch_duration: u64The amount of time in slots, that each epoch should last
This is essentially the duration of an Era
bonding_duration: u64The number of eras the bonding duration is long